## $Id: contracts.py 14184 2016-09-23 16:38:53Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Customer contract components.
"""

import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.ikoba.utils.helpers import attrs_to_fields
from waeup.ikoba.customers.interfaces import ICustomerNavigation
from waeup.ikoba.customers.contracts import ContractBase
from ikobacustom.uniben.interfaces import MessageFactory as _
from ikobacustom.uniben.customers.interfaces import (
    IRIAAContract, IRIAAContractEdit, IRIAAContractProcess,
    IRIAAContractOfficialUse)


class UnibenContract(ContractBase):
    """This is a baseclass contract.
    """

class RIAAContract(UnibenContract):
    """Research and Innovative Achievement Award
    """

    grok.implements(
        IRIAAContractProcess,
        IRIAAContract,
        IRIAAContractEdit,
        ICustomerNavigation)

    contract_category = 'riaa'

    form_fields_interface = IRIAAContract

    edit_form_fields_interface = IRIAAContractEdit

    ou_form_fields_interface = IRIAAContractOfficialUse

    check_docs_interface = IRIAAContract

RIAAContract = attrs_to_fields(RIAAContract)


# Contracts must be importable. So we might need a factory.
class RIAAContractFactory(grok.GlobalUtility):
    """A factory for RIAAContract.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.RIAAContract')
    title = u"Create a new riaa contract.",
    description = u"This factory instantiates new riaa contract instances."

    def __call__(self, *args, **kw):
        return RIAAContract(*args, **kw)

    def getInterfaces(self):
        return implementedBy(RIAAContract)
