## $Id: documents.py 14184 2016-09-23 16:38:53Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Customer document components.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.ikoba.utils.helpers import attrs_to_fields
from waeup.ikoba.customers.interfaces import ICustomerNavigation
from waeup.ikoba.customers.documents import CustomerDocumentBase
from ikobacustom.uniben.interfaces import MessageFactory as _
from ikobacustom.uniben.customers.interfaces import (
    IUnibenCustomerDocument, IUnibenCustomerPDFDocument)


class UnibenCustomerDocument(CustomerDocumentBase):
    """This is a sample customer document.
    """

    grok.implements(IUnibenCustomerDocument, ICustomerNavigation)
    grok.provides(IUnibenCustomerDocument)

    # Ikoba can store any number of files per Document object.
    # However, we highly recommend to associate and store
    # only one file per Document object. Thus the following
    # tuple should contain only a single filename string.
    filenames = ('scan',)

    form_fields_interface = IUnibenCustomerDocument

UnibenCustomerDocument = attrs_to_fields(UnibenCustomerDocument)


# Customer documents must be importable. So we need a factory.
class UnibenCustomerDocumentFactory(grok.GlobalUtility):
    """A factory for customer documents.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.UnibenCustomerDocument')
    title = u"Create a new document.",
    description = u"This factory instantiates new sample document instances."

    def __call__(self, *args, **kw):
        return UnibenCustomerDocument(*args, **kw)

    def getInterfaces(self):
        return implementedBy(UnibenCustomerDocument)

class UnibenCustomerPDFDocument(CustomerDocumentBase):
    """This is a sample customer document.
    """

    grok.implements(IUnibenCustomerPDFDocument, ICustomerNavigation)
    grok.provides(IUnibenCustomerPDFDocument)

    filenames = ('scan.pdf',)

    form_fields_interface = IUnibenCustomerPDFDocument

UnibenCustomerPDFDocument = attrs_to_fields(UnibenCustomerPDFDocument)


class UnibenCustomerPDFDocumentFactory(grok.GlobalUtility):
    """A factory for customer documents.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.UnibenCustomerPDFDocument')
    title = u"Create a new document.",
    description = u"This factory instantiates new document instances."

    def __call__(self, *args, **kw):
        return UnibenCustomerPDFDocument(*args, **kw)

    def getInterfaces(self):
        return implementedBy(UnibenCustomerPDFDocument)
